@@ -27,7 +27,8 @@ class EmrClient(AbstractClient):
 
 
     def AddUsersForUserManager(self, request):
-        """新增用户列表（用户管理）
+        """该接口支持安装了OpenLdap组件的集群。
+        新增用户列表（用户管理）。
 
         :param request: Request instance for AddUsersForUserManager.
         :type request: :class:`tencentcloud.emr.v20190103.models.AddUsersForUserManagerRequest`
@@ -85,7 +86,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeClusterNodes(self, request):
-        """查询硬件节点信息
+        """查询集群节点信息
 
         :param request: Request instance for DescribeClusterNodes.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeClusterNodesRequest`
@@ -142,6 +143,35 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeEmrApplicationStatics(self, request):
+        """yarn application 统计接口查询
+
+        :param request: Request instance for DescribeEmrApplicationStatics.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeEmrApplicationStaticsRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeEmrApplicationStaticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeEmrApplicationStatics", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEmrApplicationStaticsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeInstanceRenewNodes(self, request):
         """预付费集群隔离后续费资源查询
 
@@ -288,7 +318,8 @@ class EmrClient(AbstractClient):
 
 
     def DescribeUsersForUserManager(self, request):
-        """批量导出用户。对于kerberos集群，如果需要kertab文件下载地址，可以将NeedKeytabInfo设置为true；注意SupportDownLoadKeyTab为true，但是DownLoadKeyTabUrl为空字符串，表示keytab文件在后台没有准备好（正在生成）
+        """该接口支持安装了OpenLdap组件的集群。
+        批量导出用户。对于kerberos集群，如果需要kertab文件下载地址，可以将NeedKeytabInfo设置为true；注意SupportDownLoadKeyTab为true，但是DownLoadKeyTabUrl为空字符串，表示keytab文件在后台没有准备好（正在生成）。
 
         :param request: Request instance for DescribeUsersForUserManager.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeUsersForUserManagerRequest`
@@ -491,7 +522,7 @@ class EmrClient(AbstractClient):
 
 
     def ModifyResourceScheduleConfig(self, request):
-        """修改yarn资源调度的资源配置
+        """修改YARN资源调度的资源配置
 
         :param request: Request instance for ModifyResourceScheduleConfig.
         :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigRequest`
@@ -578,7 +609,7 @@ class EmrClient(AbstractClient):
 
 
     def ScaleOutInstance(self, request):
-        """实例扩容
+        """扩容节点
 
         :param request: Request instance for ScaleOutInstance.
         :type request: :class:`tencentcloud.emr.v20190103.models.ScaleOutInstanceRequest`
