@@ -27,7 +27,9 @@ class GpmClient(AbstractClient):
 
 
     def CancelMatching(self, request):
-        """取消匹配。
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        取消匹配。
 
         :param request: Request instance for CancelMatching.
         :type request: :class:`tencentcloud.gpm.v20200820.models.CancelMatchingRequest`
@@ -36,7 +38,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CancelMatching", params)
+            headers = request.headers
+            body = self.call("CancelMatching", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CancelMatchingResponse()
@@ -55,7 +58,9 @@ class GpmClient(AbstractClient):
 
 
     def CreateMatch(self, request):
-        """创建匹配
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        创建匹配
 
         :param request: Request instance for CreateMatch.
         :type request: :class:`tencentcloud.gpm.v20200820.models.CreateMatchRequest`
@@ -64,7 +69,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateMatch", params)
+            headers = request.headers
+            body = self.call("CreateMatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateMatchResponse()
@@ -83,7 +89,9 @@ class GpmClient(AbstractClient):
 
 
     def CreateRule(self, request):
-        """创建规则
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        创建规则
 
         :param request: Request instance for CreateRule.
         :type request: :class:`tencentcloud.gpm.v20200820.models.CreateRuleRequest`
@@ -92,7 +100,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRule", params)
+            headers = request.headers
+            body = self.call("CreateRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRuleResponse()
@@ -111,7 +120,9 @@ class GpmClient(AbstractClient):
 
 
     def DeleteMatch(self, request):
-        """删除匹配
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        删除匹配
 
         :param request: Request instance for DeleteMatch.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DeleteMatchRequest`
@@ -120,7 +131,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteMatch", params)
+            headers = request.headers
+            body = self.call("DeleteMatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteMatchResponse()
@@ -139,7 +151,9 @@ class GpmClient(AbstractClient):
 
 
     def DeleteRule(self, request):
-        """删除规则
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        删除规则
 
         :param request: Request instance for DeleteRule.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DeleteRuleRequest`
@@ -148,7 +162,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteRule", params)
+            headers = request.headers
+            body = self.call("DeleteRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteRuleResponse()
@@ -167,7 +182,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeData(self, request):
-        """统计数据
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        统计数据
 
         :param request: Request instance for DescribeData.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeDataRequest`
@@ -176,7 +193,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeData", params)
+            headers = request.headers
+            body = self.call("DescribeData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDataResponse()
@@ -195,7 +213,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeMatch(self, request):
-        """查询匹配详情
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        查询匹配详情
 
         :param request: Request instance for DescribeMatch.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeMatchRequest`
@@ -204,7 +224,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMatch", params)
+            headers = request.headers
+            body = self.call("DescribeMatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMatchResponse()
@@ -223,7 +244,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeMatchCodes(self, request):
-        """分页查询匹配Code
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        分页查询匹配Code
 
         :param request: Request instance for DescribeMatchCodes.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeMatchCodesRequest`
@@ -232,7 +255,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMatchCodes", params)
+            headers = request.headers
+            body = self.call("DescribeMatchCodes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMatchCodesResponse()
@@ -251,7 +275,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeMatches(self, request):
-        """分页查询匹配列表
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        分页查询匹配列表
 
         :param request: Request instance for DescribeMatches.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeMatchesRequest`
@@ -260,7 +286,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMatches", params)
+            headers = request.headers
+            body = self.call("DescribeMatches", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMatchesResponse()
@@ -279,7 +306,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeMatchingProgress(self, request):
-        """查询匹配进度。
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        查询匹配进度。
 
         :param request: Request instance for DescribeMatchingProgress.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeMatchingProgressRequest`
@@ -288,7 +317,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMatchingProgress", params)
+            headers = request.headers
+            body = self.call("DescribeMatchingProgress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMatchingProgressResponse()
@@ -307,7 +337,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeRule(self, request):
-        """查询规则详情
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        查询规则详情
 
         :param request: Request instance for DescribeRule.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeRuleRequest`
@@ -316,7 +348,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRule", params)
+            headers = request.headers
+            body = self.call("DescribeRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRuleResponse()
@@ -335,7 +368,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeRules(self, request):
-        """分页查询规则集列表
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        分页查询规则集列表
 
         :param request: Request instance for DescribeRules.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeRulesRequest`
@@ -344,7 +379,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRules", params)
+            headers = request.headers
+            body = self.call("DescribeRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRulesResponse()
@@ -363,7 +399,9 @@ class GpmClient(AbstractClient):
 
 
     def DescribeToken(self, request):
-        """查询匹配Token，Token用于push消息验证。
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        查询匹配Token，Token用于push消息验证。
 
         :param request: Request instance for DescribeToken.
         :type request: :class:`tencentcloud.gpm.v20200820.models.DescribeTokenRequest`
@@ -372,7 +410,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeToken", params)
+            headers = request.headers
+            body = self.call("DescribeToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTokenResponse()
@@ -391,7 +430,9 @@ class GpmClient(AbstractClient):
 
 
     def ModifyMatch(self, request):
-        """修改匹配
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        修改匹配
 
         :param request: Request instance for ModifyMatch.
         :type request: :class:`tencentcloud.gpm.v20200820.models.ModifyMatchRequest`
@@ -400,7 +441,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyMatch", params)
+            headers = request.headers
+            body = self.call("ModifyMatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyMatchResponse()
@@ -419,7 +461,9 @@ class GpmClient(AbstractClient):
 
 
     def ModifyRule(self, request):
-        """修改规则（描述、标签）
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        修改规则（描述、标签）
 
         :param request: Request instance for ModifyRule.
         :type request: :class:`tencentcloud.gpm.v20200820.models.ModifyRuleRequest`
@@ -428,7 +472,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyRule", params)
+            headers = request.headers
+            body = self.call("ModifyRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyRuleResponse()
@@ -447,7 +492,9 @@ class GpmClient(AbstractClient):
 
 
     def ModifyToken(self, request):
-        """修改匹配Token。
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        修改匹配Token。
 
         :param request: Request instance for ModifyToken.
         :type request: :class:`tencentcloud.gpm.v20200820.models.ModifyTokenRequest`
@@ -456,7 +503,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyToken", params)
+            headers = request.headers
+            body = self.call("ModifyToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyTokenResponse()
@@ -475,7 +523,9 @@ class GpmClient(AbstractClient):
 
 
     def StartMatching(self, request):
-        """支持传入一个玩家或多个玩家发起匹配，在同一个请求内的玩家将被分到同一个对局。
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        支持传入一个玩家或多个玩家发起匹配，在同一个请求内的玩家将被分到同一个对局。
 
         :param request: Request instance for StartMatching.
         :type request: :class:`tencentcloud.gpm.v20200820.models.StartMatchingRequest`
@@ -484,7 +534,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartMatching", params)
+            headers = request.headers
+            body = self.call("StartMatching", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartMatchingResponse()
@@ -503,7 +554,9 @@ class GpmClient(AbstractClient):
 
 
     def StartMatchingBackfill(self, request):
-        """通过调用StartMatchingBackfill，用户可以传入一个回填的匹配请求，GPM为回填请求搜索符合条件的ticket并形成一个新的match。
+        """此接口无法使用，游戏玩家匹配GPM已于6.1正式下架，感谢您的支持
+
+        通过调用StartMatchingBackfill，用户可以传入一个回填的匹配请求，GPM为回填请求搜索符合条件的ticket并形成一个新的match。
 
         :param request: Request instance for StartMatchingBackfill.
         :type request: :class:`tencentcloud.gpm.v20200820.models.StartMatchingBackfillRequest`
@@ -512,7 +565,8 @@ class GpmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartMatchingBackfill", params)
+            headers = request.headers
+            body = self.call("StartMatchingBackfill", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartMatchingBackfillResponse()
